@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -27,7 +27,7 @@ class EnvironmentSettingsRulesPage : public QWidget
 {
     Q_OBJECT
 public:
-    explicit EnvironmentSettingsRulesPage(QWidget *parent = Q_NULLPTR);
+    explicit EnvironmentSettingsRulesPage(QWidget *parent = nullptr);
     ~EnvironmentSettingsRulesPage();
     void setRules(const QString &rules);
 private:
